@@ -216,7 +216,7 @@ fn main() {
     let api = api.event_api();
     let chat_id = message.chat_id();
     api.get_chat(GetChat::builder().chat_id(chat_id).build())?;
-    debug!("Receive new message, from: '{:?}', data: {}", message.sender_user_id(), message.to_json().expect("Can't serialize json"));
+    debug!("Receive new message, from: '{:?}', data: {}", message.sender(), message.to_json().expect("Can't serialize json"));
     Ok(())
   });
 
