@@ -61,6 +61,11 @@ impl AsyncApi {
     async_caller(&self.api, add_chat_members.as_ref()).await
   }
 
+  pub async fn add_chat_to_list<C: AsRef<AddChatToList>>(&self, add_chat_to_list: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, add_chat_to_list.as_ref()).await
+  }
+
   pub async fn add_contact<C: AsRef<AddContact>>(&self, add_contact: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, add_contact.as_ref()).await
@@ -141,9 +146,9 @@ impl AsyncApi {
     async_caller(&self.api, answer_shipping_query.as_ref()).await
   }
 
-  pub async fn block_user<C: AsRef<BlockUser>>(&self, block_user: C) -> RTDResult<Ok> {
+  pub async fn block_message_sender_from_replies<C: AsRef<BlockMessageSenderFromReplies>>(&self, block_message_sender_from_replies: C) -> RTDResult<Ok> {
     async_caller!(Ok);
-    async_caller(&self.api, block_user.as_ref()).await
+    async_caller(&self.api, block_message_sender_from_replies.as_ref()).await
   }
 
   pub async fn can_transfer_ownership<C: AsRef<CanTransferOwnership>>(&self, can_transfer_ownership: C) -> RTDResult<CanTransferOwnershipResult> {
@@ -291,6 +296,11 @@ impl AsyncApi {
     async_caller(&self.api, create_call.as_ref()).await
   }
 
+  pub async fn create_chat_filter<C: AsRef<CreateChatFilter>>(&self, create_chat_filter: C) -> RTDResult<ChatFilterInfo> {
+    async_caller!(ChatFilterInfo);
+    async_caller(&self.api, create_chat_filter.as_ref()).await
+  }
+
   pub async fn create_new_basic_group_chat<C: AsRef<CreateNewBasicGroupChat>>(&self, create_new_basic_group_chat: C) -> RTDResult<Chat> {
     async_caller!(Chat);
     async_caller(&self.api, create_new_basic_group_chat.as_ref()).await
@@ -336,6 +346,11 @@ impl AsyncApi {
     async_caller(&self.api, delete_account.as_ref()).await
   }
 
+  pub async fn delete_chat_filter<C: AsRef<DeleteChatFilter>>(&self, delete_chat_filter: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, delete_chat_filter.as_ref()).await
+  }
+
   pub async fn delete_chat_history<C: AsRef<DeleteChatHistory>>(&self, delete_chat_history: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, delete_chat_history.as_ref()).await
@@ -421,6 +436,11 @@ impl AsyncApi {
     async_caller(&self.api, download_file.as_ref()).await
   }
 
+  pub async fn edit_chat_filter<C: AsRef<EditChatFilter>>(&self, edit_chat_filter: C) -> RTDResult<ChatFilterInfo> {
+    async_caller!(ChatFilterInfo);
+    async_caller(&self.api, edit_chat_filter.as_ref()).await
+  }
+
   pub async fn edit_custom_language_pack_info<C: AsRef<EditCustomLanguagePackInfo>>(&self, edit_custom_language_pack_info: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, edit_custom_language_pack_info.as_ref()).await
@@ -561,6 +581,11 @@ impl AsyncApi {
     async_caller(&self.api, get_backgrounds.as_ref()).await
   }
 
+  pub async fn get_bank_card_info<C: AsRef<GetBankCardInfo>>(&self, get_bank_card_info: C) -> RTDResult<BankCardInfo> {
+    async_caller!(BankCardInfo);
+    async_caller(&self.api, get_bank_card_info.as_ref()).await
+  }
+
   pub async fn get_basic_group<C: AsRef<GetBasicGroup>>(&self, get_basic_group: C) -> RTDResult<BasicGroup> {
     async_caller!(BasicGroup);
     async_caller(&self.api, get_basic_group.as_ref()).await
@@ -571,9 +596,9 @@ impl AsyncApi {
     async_caller(&self.api, get_basic_group_full_info.as_ref()).await
   }
 
-  pub async fn get_blocked_users<C: AsRef<GetBlockedUsers>>(&self, get_blocked_users: C) -> RTDResult<Users> {
-    async_caller!(Users);
-    async_caller(&self.api, get_blocked_users.as_ref()).await
+  pub async fn get_blocked_message_senders<C: AsRef<GetBlockedMessageSenders>>(&self, get_blocked_message_senders: C) -> RTDResult<MessageSenders> {
+    async_caller!(MessageSenders);
+    async_caller(&self.api, get_blocked_message_senders.as_ref()).await
   }
 
   pub async fn get_callback_query_answer<C: AsRef<GetCallbackQueryAnswer>>(&self, get_callback_query_answer: C) -> RTDResult<CallbackQueryAnswer> {
@@ -581,6 +606,11 @@ impl AsyncApi {
     async_caller(&self.api, get_callback_query_answer.as_ref()).await
   }
 
+  pub async fn get_callback_query_message<C: AsRef<GetCallbackQueryMessage>>(&self, get_callback_query_message: C) -> RTDResult<Message> {
+    async_caller!(Message);
+    async_caller(&self.api, get_callback_query_message.as_ref()).await
+  }
+
   pub async fn get_chat<C: AsRef<GetChat>>(&self, get_chat: C) -> RTDResult<Chat> {
     async_caller!(Chat);
     async_caller(&self.api, get_chat.as_ref()).await
@@ -596,11 +626,26 @@ impl AsyncApi {
     async_caller(&self.api, get_chat_event_log.as_ref()).await
   }
 
+  pub async fn get_chat_filter<C: AsRef<GetChatFilter>>(&self, get_chat_filter: C) -> RTDResult<ChatFilter> {
+    async_caller!(ChatFilter);
+    async_caller(&self.api, get_chat_filter.as_ref()).await
+  }
+
+  pub async fn get_chat_filter_default_icon_name<C: AsRef<GetChatFilterDefaultIconName>>(&self, get_chat_filter_default_icon_name: C) -> RTDResult<Text> {
+    async_caller!(Text);
+    async_caller(&self.api, get_chat_filter_default_icon_name.as_ref()).await
+  }
+
   pub async fn get_chat_history<C: AsRef<GetChatHistory>>(&self, get_chat_history: C) -> RTDResult<Messages> {
     async_caller!(Messages);
     async_caller(&self.api, get_chat_history.as_ref()).await
   }
 
+  pub async fn get_chat_lists_to_add_chat<C: AsRef<GetChatListsToAddChat>>(&self, get_chat_lists_to_add_chat: C) -> RTDResult<ChatLists> {
+    async_caller!(ChatLists);
+    async_caller(&self.api, get_chat_lists_to_add_chat.as_ref()).await
+  }
+
   pub async fn get_chat_member<C: AsRef<GetChatMember>>(&self, get_chat_member: C) -> RTDResult<ChatMember> {
     async_caller!(ChatMember);
     async_caller(&self.api, get_chat_member.as_ref()).await
@@ -631,6 +676,11 @@ impl AsyncApi {
     async_caller(&self.api, get_chat_scheduled_messages.as_ref()).await
   }
 
+  pub async fn get_chat_statistics<C: AsRef<GetChatStatistics>>(&self, get_chat_statistics: C) -> RTDResult<ChatStatistics> {
+    async_caller!(ChatStatistics);
+    async_caller(&self.api, get_chat_statistics.as_ref()).await
+  }
+
   pub async fn get_chat_statistics_url<C: AsRef<GetChatStatisticsUrl>>(&self, get_chat_statistics_url: C) -> RTDResult<HttpUrl> {
     async_caller!(HttpUrl);
     async_caller(&self.api, get_chat_statistics_url.as_ref()).await
@@ -651,6 +701,11 @@ impl AsyncApi {
     async_caller(&self.api, get_contacts.as_ref()).await
   }
 
+  pub async fn get_countries<C: AsRef<GetCountries>>(&self, get_countries: C) -> RTDResult<Countries> {
+    async_caller!(Countries);
+    async_caller(&self.api, get_countries.as_ref()).await
+  }
+
   pub async fn get_country_code<C: AsRef<GetCountryCode>>(&self, get_country_code: C) -> RTDResult<Text> {
     async_caller!(Text);
     async_caller(&self.api, get_country_code.as_ref()).await
@@ -811,6 +866,11 @@ impl AsyncApi {
     async_caller(&self.api, get_map_thumbnail_file.as_ref()).await
   }
 
+  pub async fn get_markdown_text<C: AsRef<GetMarkdownText>>(&self, get_markdown_text: C) -> RTDResult<FormattedText> {
+    async_caller!(FormattedText);
+    async_caller(&self.api, get_markdown_text.as_ref()).await
+  }
+
   pub async fn get_me<C: AsRef<GetMe>>(&self, get_me: C) -> RTDResult<User> {
     async_caller!(User);
     async_caller(&self.api, get_me.as_ref()).await
@@ -821,8 +881,13 @@ impl AsyncApi {
     async_caller(&self.api, get_message.as_ref()).await
   }
 
-  pub async fn get_message_link<C: AsRef<GetMessageLink>>(&self, get_message_link: C) -> RTDResult<HttpUrl> {
-    async_caller!(HttpUrl);
+  pub async fn get_message_embedding_code<C: AsRef<GetMessageEmbeddingCode>>(&self, get_message_embedding_code: C) -> RTDResult<Text> {
+    async_caller!(Text);
+    async_caller(&self.api, get_message_embedding_code.as_ref()).await
+  }
+
+  pub async fn get_message_link<C: AsRef<GetMessageLink>>(&self, get_message_link: C) -> RTDResult<MessageLink> {
+    async_caller!(MessageLink);
     async_caller(&self.api, get_message_link.as_ref()).await
   }
 
@@ -836,6 +901,26 @@ impl AsyncApi {
     async_caller(&self.api, get_message_locally.as_ref()).await
   }
 
+  pub async fn get_message_public_forwards<C: AsRef<GetMessagePublicForwards>>(&self, get_message_public_forwards: C) -> RTDResult<FoundMessages> {
+    async_caller!(FoundMessages);
+    async_caller(&self.api, get_message_public_forwards.as_ref()).await
+  }
+
+  pub async fn get_message_statistics<C: AsRef<GetMessageStatistics>>(&self, get_message_statistics: C) -> RTDResult<MessageStatistics> {
+    async_caller!(MessageStatistics);
+    async_caller(&self.api, get_message_statistics.as_ref()).await
+  }
+
+  pub async fn get_message_thread<C: AsRef<GetMessageThread>>(&self, get_message_thread: C) -> RTDResult<MessageThreadInfo> {
+    async_caller!(MessageThreadInfo);
+    async_caller(&self.api, get_message_thread.as_ref()).await
+  }
+
+  pub async fn get_message_thread_history<C: AsRef<GetMessageThreadHistory>>(&self, get_message_thread_history: C) -> RTDResult<Messages> {
+    async_caller!(Messages);
+    async_caller(&self.api, get_message_thread_history.as_ref()).await
+  }
+
   pub async fn get_messages<C: AsRef<GetMessages>>(&self, get_messages: C) -> RTDResult<Messages> {
     async_caller!(Messages);
     async_caller(&self.api, get_messages.as_ref()).await
@@ -881,6 +966,11 @@ impl AsyncApi {
     async_caller(&self.api, get_payment_receipt.as_ref()).await
   }
 
+  pub async fn get_phone_number_info<C: AsRef<GetPhoneNumberInfo>>(&self, get_phone_number_info: C) -> RTDResult<PhoneNumberInfo> {
+    async_caller!(PhoneNumberInfo);
+    async_caller(&self.api, get_phone_number_info.as_ref()).await
+  }
+
   pub async fn get_poll_voters<C: AsRef<GetPollVoters>>(&self, get_poll_voters: C) -> RTDResult<Users> {
     async_caller!(Users);
     async_caller(&self.api, get_poll_voters.as_ref()).await
@@ -901,11 +991,6 @@ impl AsyncApi {
     async_caller(&self.api, get_proxy_link.as_ref()).await
   }
 
-  pub async fn get_public_message_link<C: AsRef<GetPublicMessageLink>>(&self, get_public_message_link: C) -> RTDResult<PublicMessageLink> {
-    async_caller!(PublicMessageLink);
-    async_caller(&self.api, get_public_message_link.as_ref()).await
-  }
-
   pub async fn get_push_receiver_id<C: AsRef<GetPushReceiverId>>(&self, get_push_receiver_id: C) -> RTDResult<PushReceiverId> {
     async_caller!(PushReceiverId);
     async_caller(&self.api, get_push_receiver_id.as_ref()).await
@@ -926,6 +1011,11 @@ impl AsyncApi {
     async_caller(&self.api, get_recently_visited_t_me_urls.as_ref()).await
   }
 
+  pub async fn get_recommended_chat_filters<C: AsRef<GetRecommendedChatFilters>>(&self, get_recommended_chat_filters: C) -> RTDResult<RecommendedChatFilters> {
+    async_caller!(RecommendedChatFilters);
+    async_caller(&self.api, get_recommended_chat_filters.as_ref()).await
+  }
+
   pub async fn get_recovery_email_address<C: AsRef<GetRecoveryEmailAddress>>(&self, get_recovery_email_address: C) -> RTDResult<RecoveryEmailAddress> {
     async_caller!(RecoveryEmailAddress);
     async_caller(&self.api, get_recovery_email_address.as_ref()).await
@@ -961,6 +1051,11 @@ impl AsyncApi {
     async_caller(&self.api, get_secret_chat.as_ref()).await
   }
 
+  pub async fn get_statistical_graph<C: AsRef<GetStatisticalGraph>>(&self, get_statistical_graph: C) -> RTDResult<StatisticalGraph> {
+    async_caller!(StatisticalGraph);
+    async_caller(&self.api, get_statistical_graph.as_ref()).await
+  }
+
   pub async fn get_sticker_emojis<C: AsRef<GetStickerEmojis>>(&self, get_sticker_emojis: C) -> RTDResult<Emojis> {
     async_caller!(Emojis);
     async_caller(&self.api, get_sticker_emojis.as_ref()).await
@@ -1046,8 +1141,8 @@ impl AsyncApi {
     async_caller(&self.api, get_user_privacy_setting_rules.as_ref()).await
   }
 
-  pub async fn get_user_profile_photos<C: AsRef<GetUserProfilePhotos>>(&self, get_user_profile_photos: C) -> RTDResult<UserProfilePhotos> {
-    async_caller!(UserProfilePhotos);
+  pub async fn get_user_profile_photos<C: AsRef<GetUserProfilePhotos>>(&self, get_user_profile_photos: C) -> RTDResult<ChatPhotos> {
+    async_caller!(ChatPhotos);
     async_caller(&self.api, get_user_profile_photos.as_ref()).await
   }
 
@@ -1061,6 +1156,11 @@ impl AsyncApi {
     async_caller(&self.api, get_web_page_preview.as_ref()).await
   }
 
+  pub async fn hide_suggested_action<C: AsRef<HideSuggestedAction>>(&self, hide_suggested_action: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, hide_suggested_action.as_ref()).await
+  }
+
   pub async fn import_contacts<C: AsRef<ImportContacts>>(&self, import_contacts: C) -> RTDResult<ImportedContacts> {
     async_caller!(ImportedContacts);
     async_caller(&self.api, import_contacts.as_ref()).await
@@ -1101,6 +1201,11 @@ impl AsyncApi {
     async_caller(&self.api, optimize_storage.as_ref()).await
   }
 
+  pub async fn parse_markdown<C: AsRef<ParseMarkdown>>(&self, parse_markdown: C) -> RTDResult<FormattedText> {
+    async_caller!(FormattedText);
+    async_caller(&self.api, parse_markdown.as_ref()).await
+  }
+
   pub async fn parse_text_entities<C: AsRef<ParseTextEntities>>(&self, parse_text_entities: C) -> RTDResult<FormattedText> {
     async_caller!(FormattedText);
     async_caller(&self.api, parse_text_entities.as_ref()).await
@@ -1216,6 +1321,11 @@ impl AsyncApi {
     async_caller(&self.api, remove_top_chat.as_ref()).await
   }
 
+  pub async fn reorder_chat_filters<C: AsRef<ReorderChatFilters>>(&self, reorder_chat_filters: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, reorder_chat_filters.as_ref()).await
+  }
+
   pub async fn reorder_installed_sticker_sets<C: AsRef<ReorderInstalledStickerSets>>(&self, reorder_installed_sticker_sets: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, reorder_installed_sticker_sets.as_ref()).await
@@ -1411,6 +1521,11 @@ impl AsyncApi {
     async_caller(&self.api, send_call_rating.as_ref()).await
   }
 
+  pub async fn send_call_signaling_data<C: AsRef<SendCallSignalingData>>(&self, send_call_signaling_data: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, send_call_signaling_data.as_ref()).await
+  }
+
   pub async fn send_chat_action<C: AsRef<SendChatAction>>(&self, send_chat_action: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, send_chat_action.as_ref()).await
@@ -1506,11 +1621,6 @@ impl AsyncApi {
     async_caller(&self.api, set_bot_updates_status.as_ref()).await
   }
 
-  pub async fn set_chat_chat_list<C: AsRef<SetChatChatList>>(&self, set_chat_chat_list: C) -> RTDResult<Ok> {
-    async_caller!(Ok);
-    async_caller(&self.api, set_chat_chat_list.as_ref()).await
-  }
-
   pub async fn set_chat_client_data<C: AsRef<SetChatClientData>>(&self, set_chat_client_data: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_chat_client_data.as_ref()).await
@@ -1566,6 +1676,11 @@ impl AsyncApi {
     async_caller(&self.api, set_chat_title.as_ref()).await
   }
 
+  pub async fn set_commands<C: AsRef<SetCommands>>(&self, set_commands: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_commands.as_ref()).await
+  }
+
   pub async fn set_custom_language_pack<C: AsRef<SetCustomLanguagePack>>(&self, set_custom_language_pack: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_custom_language_pack.as_ref()).await
@@ -1596,6 +1711,11 @@ impl AsyncApi {
     async_caller(&self.api, set_inline_game_score.as_ref()).await
   }
 
+  pub async fn set_location<C: AsRef<SetLocation>>(&self, set_location: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, set_location.as_ref()).await
+  }
+
   pub async fn set_log_stream<C: AsRef<SetLogStream>>(&self, set_log_stream: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_log_stream.as_ref()).await
@@ -1671,6 +1791,11 @@ impl AsyncApi {
     async_caller(&self.api, set_sticker_position_in_set.as_ref()).await
   }
 
+  pub async fn set_sticker_set_thumbnail<C: AsRef<SetStickerSetThumbnail>>(&self, set_sticker_set_thumbnail: C) -> RTDResult<StickerSet> {
+    async_caller!(StickerSet);
+    async_caller(&self.api, set_sticker_set_thumbnail.as_ref()).await
+  }
+
   pub async fn set_supergroup_sticker_set<C: AsRef<SetSupergroupStickerSet>>(&self, set_supergroup_sticker_set: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, set_supergroup_sticker_set.as_ref()).await
@@ -1801,6 +1926,11 @@ impl AsyncApi {
     async_caller(&self.api, toggle_chat_is_pinned.as_ref()).await
   }
 
+  pub async fn toggle_message_sender_is_blocked<C: AsRef<ToggleMessageSenderIsBlocked>>(&self, toggle_message_sender_is_blocked: C) -> RTDResult<Ok> {
+    async_caller!(Ok);
+    async_caller(&self.api, toggle_message_sender_is_blocked.as_ref()).await
+  }
+
   pub async fn toggle_supergroup_is_all_history_available<C: AsRef<ToggleSupergroupIsAllHistoryAvailable>>(&self, toggle_supergroup_is_all_history_available: C) -> RTDResult<Ok> {
     async_caller!(Ok);
     async_caller(&self.api, toggle_supergroup_is_all_history_available.as_ref()).await
@@ -1816,9 +1946,9 @@ impl AsyncApi {
     async_caller(&self.api, transfer_chat_ownership.as_ref()).await
   }
 
-  pub async fn unblock_user<C: AsRef<UnblockUser>>(&self, unblock_user: C) -> RTDResult<Ok> {
+  pub async fn unpin_all_chat_messages<C: AsRef<UnpinAllChatMessages>>(&self, unpin_all_chat_messages: C) -> RTDResult<Ok> {
     async_caller!(Ok);
-    async_caller(&self.api, unblock_user.as_ref()).await
+    async_caller(&self.api, unpin_all_chat_messages.as_ref()).await
   }
 
   pub async fn unpin_chat_message<C: AsRef<UnpinChatMessage>>(&self, unpin_chat_message: C) -> RTDResult<Ok> {
